Inline XBRL Sample - Valeo Income Statement

# 5.4.1 Consolidated statement of income

(in millions of euros) | Notes | 2014 | 2013 restated (7)
--- | --- | --- | ---
Sales | 4.1 | 12,725 | 11,662
Cost of sales | 4.3 | ( 10,522) | ( 9,653)
GROSS MARGIN | 4.3 | 2,203 | 2,009
% of sales |  | 17.3% | 17.2%
Research and Development expenditure, net | 4.51 | ( 685) | ( 614)
Selling expenses |  | ( 207) | ( 193)
Administrative expenses |  | ( 449) | ( 436)
Operating margin |  | 862 | 766
% of sales |  | 6.8% | 6.6%
Share in net earnings of equity-accounted companies | 4.5 3.1 | 51 | 26
Operating margin including share in net earnings of equity-accounted companies | 4.5 | 913 | 792

These samples have been prepared by XBRL International as a technology demonstration, and the accuracy of figures and information contained within this sample should not be relied upon for any purpose whatsoever.

### Link target

Figure tagged in two reports 1,234.

Figure tagged in three reports 1,234.

### Non-ASCII link target